// gen_m version 2018.01.11
`timescale 1ns/10ps
module  sim_ASYNC_FIFO8X72_LATCH
(
    bist_fail,      // memory BIST fail, 1 : BIST fail, 0 : BIST PASS
    bist_finish,    // 1: BIST finished, 0: idle of testing memory
    test_mode,      // 1: SCAN mode, 0: normal mode
    SCAN_ENABLE,
    bist_mode,      // 1: memory BIST mode, 0: normal mode
    rdata,          // FIFO read data
    wfull,          // FIFO full
    rempty,         // FIFO empty
    wdata,          // FIFO write data
    winc,           // FIFO active high write enable
    wclk,           // FIFO write clock
    wrst_n,         // FIFO active low reset in write clock domain
    rinc,           // FIFO active high read enable
    rclk,           // FIFO read clock
    rrst_n,         // FIFO active low reset in read clock domain
    NVIC_RST_B,     // global Novelics resetb (should be connected to HW_CFG_SET_RST_B)
    asfifo_lp_dis   // low power control of memory, 1: disable clock gating and chip enable control of memory, 0: enable
);

parameter AW   = 3;
parameter DW   = 72;
parameter DN   = 8;

output [71:0] rdata; // FIFO read data
output bist_fail;    // memory BIST fail, 1 : BIST fail, 0 : BIST PASS
output bist_finish;  // 1: BIST finished, 0: idle of testing memory
output wfull;        // FIFO full
output rempty;       // FIFO empty
input [71:0] wdata; // FIFO write data
input winc;          // FIFO active high write enable
input wclk;          // FIFO write clock
input wrst_n;        // FIFO active low reset in write clock domain
input rinc;          // FIFO active high read enable
input rclk;          // FIFO read clock
input rrst_n;        // FIFO active low reset in read clock domain
input NVIC_RST_B;
input asfifo_lp_dis; // low power control of memory, 1: disable clock gating and chip enable control of memory, 0: enable
input test_mode;     // 1: SCAN mode, 0: normal mode
input bist_mode;     // 1: memory BIST mode, 0: normal mode
input SCAN_ENABLE;

wire async_fifo_empty_pre;
wire async_fifo_rd_pre;


wire rclkSW  = (test_mode) ? wclk : rclk;
wire rrst_nSW = (test_mode) ? wrst_n : rrst_n;

FPGA_SCALAFIFO8x72 #(AW,DN,DW)  I_SCALAFIFO_0
(
   .WCLK(wclk),
   .WRSTN(wrst_n),
   .WSWRST(1'b0),
   .WRITE(winc),
   .WDATA(wdata),
   .WFULL(wfull),
   .WDEPTH(),

   .RCLK(rclkSW),
   .RRSTN(rrst_nSW),
   .RSWRST(1'b0),
   .READ(async_fifo_rd_pre),
   .RDATA(rdata),
   .REMPTY(async_fifo_empty_pre),
   .RDEPTH(),

   .bist_fail     (bist_fail),
   .bist_finish   (bist_finish),
   .bist_mode     (bist_mode),
   .test_mode     (test_mode),
   .asfifo_lp_dis (asfifo_lp_dis)
);


FPGA_REMPTY_SCALAFIFO_to_ASFIFO8x72 I_REMPTY_SCALAFIFO_to_ASFIFO_0 (
    .ASFIFO_REMPTY(rempty), //out
    .SCALAFIFO_REMPTY(async_fifo_empty_pre),
    .SCALAFIFO_READ(async_fifo_rd_pre), //out
    .ASFIFO_READ(rinc),
    .RCLK(rclkSW),
    .RRST_B(rrst_nSW)
);

endmodule

module FPGA_REMPTY_SCALAFIFO_to_ASFIFO8x72 (
    output  reg ASFIFO_REMPTY,
    input   SCALAFIFO_REMPTY,
    output  reg SCALAFIFO_READ,
    input   ASFIFO_READ,
    input   RCLK,
    input   RRST_B
);

reg SCALAFIFO_REMPTY_DLY;
reg SCALAFIFO_REMPTY_HIGH_2_LOW;

  always @(posedge RCLK or negedge RRST_B)
  if( !RRST_B )
    SCALAFIFO_REMPTY_DLY <= #1 1'b1;
  else
    SCALAFIFO_REMPTY_DLY <= #1 SCALAFIFO_REMPTY;

  always @(*)
    SCALAFIFO_REMPTY_HIGH_2_LOW = !SCALAFIFO_REMPTY & SCALAFIFO_REMPTY_DLY;

reg LAST_DATA;

  always @(posedge RCLK or negedge RRST_B)
  if( !RRST_B )
    LAST_DATA <= #1 1'b0;
  else if ( !LAST_DATA )
    LAST_DATA <= #1 SCALAFIFO_REMPTY & !SCALAFIFO_REMPTY_DLY & !ASFIFO_READ;
  else if ( LAST_DATA )
    LAST_DATA <= !ASFIFO_READ;

reg IMPLY_READ;

  always @(*)
    IMPLY_READ = SCALAFIFO_REMPTY_HIGH_2_LOW & !LAST_DATA;

  always @(*)
    SCALAFIFO_READ = IMPLY_READ | (ASFIFO_READ && !SCALAFIFO_REMPTY);

  always @(*)
    ASFIFO_REMPTY = (SCALAFIFO_REMPTY_DLY | SCALAFIFO_REMPTY_HIGH_2_LOW) & !LAST_DATA;

endmodule


module FPGA_SCALRPTR8x72
(
    RDEPTH,
    REMPTY,
    RADDR,
    RPTR,
    WPTR,
    RINC,
    RCLK,
    RRSTN,
    SWRST
);  // synopsys template
    //=====================================================
    // parameter
    //=====================================================
    `define     SCA_DLY #1
    parameter       AW = 2;
    parameter       DN = 4;
    //=====================================================
    // external signals
    //=====================================================
    output  [AW:0]      RDEPTH;
    output              REMPTY;
    output  [AW-1:0]    RADDR;
    output  [AW:0]      RPTR;
    input   [AW:0]      WPTR;
    input               RINC;
    input               RCLK;
    input               RRSTN;
    input               SWRST;

    //---------------------------------
    reg     [AW:0]      RDEPTH;
    wire                REMPTY;
    reg     [AW-1:0]    RADDR;
    reg     [AW:0]      RPTR;

    //=====================================================
    // internal signals
    //=====================================================
    reg     [AW:0]      RBIN;
    wire    [AW:0]      RGRAYNEXT;
    wire    [AW:0]      RBINNEXT;
    reg     [AW:0]      WPTR_SYN1;
    reg     [AW:0]      WPTR_SYN2;
    wire                RTOP;
    wire    [15:0]      WBIN;


    //=====================================================
    // RDEPTH
    //=====================================================
    always @(posedge RCLK or negedge RRSTN)
    begin
        if(~RRSTN)
        begin
            WPTR_SYN1   <= `SCA_DLY 0;
            WPTR_SYN2   <= `SCA_DLY 0;
        end
        else if(SWRST)
        begin
            WPTR_SYN1   <= `SCA_DLY 0;
            WPTR_SYN2   <= `SCA_DLY 0;
        end
        else
        begin
            WPTR_SYN1   <= `SCA_DLY WPTR;
            WPTR_SYN2   <= `SCA_DLY WPTR_SYN1;
        end
    end

    assign  WBIN[0]     = ^(WPTR_SYN2 >> 0 );
    assign  WBIN[1]     = ^(WPTR_SYN2 >> 1 );
    assign  WBIN[2]     = ^(WPTR_SYN2 >> 2 );
    assign  WBIN[3]     = ^(WPTR_SYN2 >> 3 );
    assign  WBIN[4]     = ^(WPTR_SYN2 >> 4 );
    assign  WBIN[5]     = ^(WPTR_SYN2 >> 5 );
    assign  WBIN[6]     = ^(WPTR_SYN2 >> 6 );
    assign  WBIN[7]     = ^(WPTR_SYN2 >> 7 );
    assign  WBIN[8]     = ^(WPTR_SYN2 >> 8 );
    assign  WBIN[9]     = ^(WPTR_SYN2 >> 9 );
    assign  WBIN[10]    = ^(WPTR_SYN2 >> 10);
    assign  WBIN[11]    = ^(WPTR_SYN2 >> 11);
    assign  WBIN[12]    = ^(WPTR_SYN2 >> 12);
    assign  WBIN[13]    = ^(WPTR_SYN2 >> 13);
    assign  WBIN[14]    = ^(WPTR_SYN2 >> 14);
    assign  WBIN[15]    = ^(WPTR_SYN2 >> 15);

    always @(posedge RCLK or negedge RRSTN)
    begin
        if(~RRSTN)      RDEPTH  <= `SCA_DLY 0;
        else if(SWRST)  RDEPTH  <= `SCA_DLY 0;
        else            RDEPTH  <= `SCA_DLY WBIN[AW:0] - RBINNEXT;
    end


    //=====================================================
    // REMPTY
    // RADDR
    // RPTR
    //=====================================================
    always @(posedge RCLK or negedge RRSTN)
    begin
        if(~RRSTN)      RBIN    <= `SCA_DLY 0;
        else if(SWRST)  RBIN    <= `SCA_DLY 0;
        else            RBIN    <= `SCA_DLY RBINNEXT;
    end

    always @(posedge RCLK or negedge RRSTN)
    begin
        if(~RRSTN)      RPTR    <= `SCA_DLY 0;
        else if(SWRST)  RPTR    <= `SCA_DLY 0;
        else            RPTR    <= `SCA_DLY RGRAYNEXT;
    end

    always @(posedge RCLK or negedge RRSTN)
    begin
        if(~RRSTN)      RADDR   <= `SCA_DLY 0;
        else if(SWRST)  RADDR   <= `SCA_DLY 0;
        else if(RINC & (~REMPTY))
        begin
            if(RTOP)    RADDR   <= `SCA_DLY 0;
            else        RADDR   <= `SCA_DLY RADDR + 1;
        end
    end

    assign  RBINNEXT    = RBIN + (RINC & (~REMPTY));
    assign  RGRAYNEXT   = (RBINNEXT >> 1) ^ RBINNEXT;
    assign  REMPTY      = (RDEPTH == 0);
    assign  RTOP        = (RADDR == (DN-1));


endmodule

module FPGA_SCALWPTR8x72
(
    WDEPTH,
    WFULL,
    WADDR,
    WPTR,
    RPTR,
    WINC,
    WCLK,
    WRSTN,
    SWRST
);  // synopsys template
    //=====================================================
    // parameter
    //=====================================================
    `define     SCA_DLY #1
    parameter       AW = 2;
    parameter       DN = 4;


    //=====================================================
    // external signals
    //=====================================================
    output  [AW:0]      WDEPTH;
    output              WFULL;
    output  [AW-1:0]    WADDR;
    output  [AW:0]      WPTR;
    input   [AW:0]      RPTR;
    input               WINC;
    input               WCLK;
    input               WRSTN;
    input               SWRST;

    //---------------------------------
    reg     [AW:0]      WDEPTH;
    wire                WFULL;
    reg     [AW-1:0]    WADDR;
    reg     [AW:0]      WPTR;

    //=====================================================
    // internal signals
    //=====================================================
    reg     [AW:0]      WBIN;
    wire    [AW:0]      WGRAYNEXT;
    wire    [AW:0]      WBINNEXT;
    reg     [AW:0]      RPTR_SYN1;
    reg     [AW:0]      RPTR_SYN2;
    wire                WTOP;
    wire    [15:0]      RBIN;


    //=====================================================
    // WDEPTH
    //=====================================================
    always @(posedge WCLK or negedge WRSTN)
    begin
        if(~WRSTN)
        begin
            RPTR_SYN1   <= `SCA_DLY 0;
            RPTR_SYN2   <= `SCA_DLY 0;
        end
        else if(SWRST)
        begin
            RPTR_SYN1   <= `SCA_DLY 0;
            RPTR_SYN2   <= `SCA_DLY 0;
        end
        else
        begin
            RPTR_SYN1   <= `SCA_DLY RPTR;
            RPTR_SYN2   <= `SCA_DLY RPTR_SYN1;
        end
    end

    assign  RBIN[0]     = ^(RPTR_SYN2 >> 0 );
    assign  RBIN[1]     = ^(RPTR_SYN2 >> 1 );
    assign  RBIN[2]     = ^(RPTR_SYN2 >> 2 );
    assign  RBIN[3]     = ^(RPTR_SYN2 >> 3 );
    assign  RBIN[4]     = ^(RPTR_SYN2 >> 4 );
    assign  RBIN[5]     = ^(RPTR_SYN2 >> 5 );
    assign  RBIN[6]     = ^(RPTR_SYN2 >> 6 );
    assign  RBIN[7]     = ^(RPTR_SYN2 >> 7 );
    assign  RBIN[8]     = ^(RPTR_SYN2 >> 8 );
    assign  RBIN[9]     = ^(RPTR_SYN2 >> 9 );
    assign  RBIN[10]    = ^(RPTR_SYN2 >> 10);
    assign  RBIN[11]    = ^(RPTR_SYN2 >> 11);
    assign  RBIN[12]    = ^(RPTR_SYN2 >> 12);
    assign  RBIN[13]    = ^(RPTR_SYN2 >> 13);
    assign  RBIN[14]    = ^(RPTR_SYN2 >> 14);
    assign  RBIN[15]    = ^(RPTR_SYN2 >> 15);

    always @(posedge WCLK or negedge WRSTN)
    begin
        if(~WRSTN)      WDEPTH  <= `SCA_DLY 0;
        else if(SWRST)  WDEPTH  <= `SCA_DLY 0;
        else            WDEPTH  <= `SCA_DLY WBINNEXT - RBIN[AW:0];
    end


    //=====================================================
    // WEMPTY
    // WADDR
    // WPTR
    //=====================================================
    always @(posedge WCLK or negedge WRSTN)
    begin
        if(~WRSTN)      WBIN    <= `SCA_DLY 0;
        else if(SWRST)  WBIN    <= `SCA_DLY 0;
        else            WBIN    <= `SCA_DLY WBINNEXT;
    end
    always @(posedge WCLK or negedge WRSTN)
    begin
        if(~WRSTN)      WPTR    <= `SCA_DLY 0;
        else if(SWRST)  WPTR    <= `SCA_DLY 0;
        else            WPTR    <= `SCA_DLY WGRAYNEXT;
    end

    always @(posedge WCLK or negedge WRSTN)
    begin
        if(~WRSTN)      WADDR   <= `SCA_DLY 0;
        else if(SWRST)  WADDR   <= `SCA_DLY 0;
        else if(WINC & (~WFULL))
        begin
            if(WTOP)    WADDR   <= `SCA_DLY 0;
            else        WADDR   <= `SCA_DLY WADDR + 1;
        end
    end

    assign  WBINNEXT    = WBIN + (WINC & (~WFULL));
    assign  WGRAYNEXT   = (WBINNEXT >> 1) ^ WBINNEXT;
    assign  WFULL       = (WDEPTH >= (DN));
    assign  WTOP        = (WADDR == (DN-1));


endmodule

module FPGA_SCALAFIFO8x72
(
    WCLK,
    WRSTN,
    WSWRST,
    WRITE,
    WDATA,
    WFULL,
    WDEPTH,

    RCLK,
    RRSTN,
    RSWRST,
    READ,
    RDATA,
    REMPTY,
    RDEPTH,

    bist_fail,
    bist_finish,
    test_mode,
    bist_mode,
    asfifo_lp_dis
);  // synopsys template
    //=====================================================
    // parameter
    //=====================================================
    `define     SCA_DLY #1
parameter       AW = 2;
parameter       DN = 4;
parameter       DW = 32;
    //=====================================================
    // external signals
    //=====================================================
    input               WCLK;       // write clk
    input               WRSTN;      // write reset
    input               WSWRST;     // write sw reset
    input               WRITE;      // write enable (high active)
    input   [DW-1:0]    WDATA;      // write data
    output              WFULL;      // write full index
    output  [AW:0]      WDEPTH;     // write fifo depth

    input               RCLK;       // read clk
    input               RRSTN;      // read reset
    input               RSWRST;     // read sw reset
    input               READ;       // read enable (high active)
    output  [DW-1:0]    RDATA;      // read data
    output              REMPTY;     // read empty index
    output  [AW:0]      RDEPTH;     // read fifo depth

    output              bist_fail;
    output              bist_finish;
    input               test_mode;
    input               bist_mode;
    input               asfifo_lp_dis;
    //---------------------------------
    
    //=====================================================
    // internal signals
    //=====================================================
    wire    [AW-1:0]    WADDR;
    wire    [AW-1:0]    RADDR;
    wire    [AW:0]      WPTR;
    wire    [AW:0]      RPTR;
    wire                WEN;
    wire                REN;



    
    //=====================================================
    // WDEPTH
    // WFULL
    // WADDR
    // WPTR
    //=====================================================
    FPGA_SCALWPTR8x72    #(AW,DN) U_WPTR
    (   
        .WDEPTH     (WDEPTH     ),
        .WFULL      (WFULL      ),
        .WADDR      (WADDR      ),
        .WPTR       (WPTR       ),
        .RPTR       (RPTR       ),
        .WINC       (WRITE      ),
        .WCLK       (WCLK       ),
        .WRSTN      (WRSTN      ),
        .SWRST      (WSWRST     )
    );

    
    //=====================================================
    // RDEPTH
    // REMPTY
    // RADDR
    // RPTR
    //=====================================================
    FPGA_SCALRPTR8x72    #(AW,DN) U_RPTR
    (   
        .RDEPTH     (RDEPTH     ),
        .REMPTY     (REMPTY     ),
        .RADDR      (RADDR      ),
        .RPTR       (RPTR       ),
        .WPTR       (WPTR       ),
        .RINC       (READ       ),
        .RCLK       (RCLK       ),
        .RRSTN      (RRSTN      ),
        .SWRST      (RSWRST     )
    );
    
    //=====================================================
    // WEN
    // REN
    // RDATA
    //=====================================================
    assign  WEN     = WRITE & (~WFULL);
    assign  REN     = READ & (~REMPTY);


DP8X72 DP8X72_0(
        .addra(WADDR),
        .addrb(RADDR),
        .clka(WCLK),
        .clkb(RCLK),
	.dina(WDATA),
        .doutb(RDATA),
        .enb(REN),
        .wea(WEN));


endmodule
/*******************************************************************************
*     This file is owned and controlled by Xilinx and must be used solely      *
*     for design, simulation, implementation and creation of design files      *
*     limited to Xilinx devices or technologies. Use with non-Xilinx           *
*     devices or technologies is expressly prohibited and immediately          *
*     terminates your license.                                                 *
*                                                                              *
*     XILINX IS PROVIDING THIS DESIGN, CODE, OR INFORMATION "AS IS" SOLELY     *
*     FOR USE IN DEVELOPING PROGRAMS AND SOLUTIONS FOR XILINX DEVICES.  BY     *
*     PROVIDING THIS DESIGN, CODE, OR INFORMATION AS ONE POSSIBLE              *
*     IMPLEMENTATION OF THIS FEATURE, APPLICATION OR STANDARD, XILINX IS       *
*     MAKING NO REPRESENTATION THAT THIS IMPLEMENTATION IS FREE FROM ANY       *
*     CLAIMS OF INFRINGEMENT, AND YOU ARE RESPONSIBLE FOR OBTAINING ANY        *
*     RIGHTS YOU MAY REQUIRE FOR YOUR IMPLEMENTATION.  XILINX EXPRESSLY        *
*     DISCLAIMS ANY WARRANTY WHATSOEVER WITH RESPECT TO THE ADEQUACY OF THE    *
*     IMPLEMENTATION, INCLUDING BUT NOT LIMITED TO ANY WARRANTIES OR           *
*     REPRESENTATIONS THAT THIS IMPLEMENTATION IS FREE FROM CLAIMS OF          *
*     INFRINGEMENT, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A    *
*     PARTICULAR PURPOSE.                                                      *
*                                                                              *
*     Xilinx products are not intended for use in life support appliances,     *
*     devices, or systems.  Use in such applications are expressly             *
*     prohibited.                                                              *
*                                                                              *
*     (c) Copyright 1995-2018 Xilinx, Inc.                                     *
*     All rights reserved.                                                     *
*******************************************************************************/
// You must compile the wrapper file DP8X72.v when simulating
// the core, DP8X72. When compiling the wrapper file, be sure to
// reference the XilinxCoreLib Verilog simulation library. For detailed
// instructions, please refer to the "CORE Generator Help".

// The synthesis directives "translate_off/translate_on" specified below are
// supported by Xilinx, Mentor Graphics and Synplicity synthesis
// tools. Ensure they are correct for your synthesis tool(s).

`timescale 1ns/1ps

module DP8X72(
  clka,
  wea,
  addra,
  dina,
  clkb,
  enb,
  addrb,
  doutb
);

input clka;
input [0 : 0] wea;
input [2 : 0] addra;
input [71 : 0] dina;
input clkb;
input enb;
input [2 : 0] addrb;
output [71 : 0] doutb;

// synthesis translate_off

  BLK_MEM_GEN_V7_3 #(
    .C_ADDRA_WIDTH(3),
    .C_ADDRB_WIDTH(3),
    .C_ALGORITHM(1),
    .C_AXI_ID_WIDTH(4),
    .C_AXI_SLAVE_TYPE(0),
    .C_AXI_TYPE(1),
    .C_BYTE_SIZE(9),
    .C_COMMON_CLK(0),
    .C_DEFAULT_DATA("0"),
    .C_DISABLE_WARN_BHV_COLL(0),
    .C_DISABLE_WARN_BHV_RANGE(0),
    .C_ENABLE_32BIT_ADDRESS(0),
    .C_FAMILY("zynq"),
    .C_HAS_AXI_ID(0),
    .C_HAS_ENA(0),
    .C_HAS_ENB(1),
    .C_HAS_INJECTERR(0),
    .C_HAS_MEM_OUTPUT_REGS_A(0),
    .C_HAS_MEM_OUTPUT_REGS_B(0),
    .C_HAS_MUX_OUTPUT_REGS_A(0),
    .C_HAS_MUX_OUTPUT_REGS_B(0),
    .C_HAS_REGCEA(0),
    .C_HAS_REGCEB(0),
    .C_HAS_RSTA(0),
    .C_HAS_RSTB(0),
    .C_HAS_SOFTECC_INPUT_REGS_A(0),
    .C_HAS_SOFTECC_OUTPUT_REGS_B(0),
    .C_INIT_FILE("BlankString"),
    .C_INIT_FILE_NAME("no_coe_file_loaded"),
    .C_INITA_VAL("0"),
    .C_INITB_VAL("0"),
    .C_INTERFACE_TYPE(0),
    .C_LOAD_INIT_FILE(0),
    .C_MEM_TYPE(1),
    .C_MUX_PIPELINE_STAGES(0),
    .C_PRIM_TYPE(1),
    .C_READ_DEPTH_A(8),
    .C_READ_DEPTH_B(8),
    .C_READ_WIDTH_A(72),
    .C_READ_WIDTH_B(72),
    .C_RST_PRIORITY_A("CE"),
    .C_RST_PRIORITY_B("CE"),
    .C_RST_TYPE("SYNC"),
    .C_RSTRAM_A(0),
    .C_RSTRAM_B(0),
    .C_SIM_COLLISION_CHECK("ALL"),
    .C_USE_BRAM_BLOCK(0),
    .C_USE_BYTE_WEA(0),
    .C_USE_BYTE_WEB(0),
    .C_USE_DEFAULT_DATA(0),
    .C_USE_ECC(0),
    .C_USE_SOFTECC(0),
    .C_WEA_WIDTH(1),
    .C_WEB_WIDTH(1),
    .C_WRITE_DEPTH_A(8),
    .C_WRITE_DEPTH_B(8),
    .C_WRITE_MODE_A("WRITE_FIRST"),
    .C_WRITE_MODE_B("WRITE_FIRST"),
    .C_WRITE_WIDTH_A(72),
    .C_WRITE_WIDTH_B(72),
    .C_XDEVICEFAMILY("zynq")
  )
  inst (
    .CLKA(clka),
    .WEA(wea),
    .ADDRA(addra),
    .DINA(dina),
    .CLKB(clkb),
    .ENB(enb),
    .ADDRB(addrb),
    .DOUTB(doutb),
    .RSTA(),
    .ENA(),
    .REGCEA(),
    .DOUTA(),
    .RSTB(),
    .REGCEB(),
    .WEB(),
    .DINB(),
    .INJECTSBITERR(),
    .INJECTDBITERR(),
    .SBITERR(),
    .DBITERR(),
    .RDADDRECC(),
    .S_ACLK(),
    .S_ARESETN(),
    .S_AXI_AWID(),
    .S_AXI_AWADDR(),
    .S_AXI_AWLEN(),
    .S_AXI_AWSIZE(),
    .S_AXI_AWBURST(),
    .S_AXI_AWVALID(),
    .S_AXI_AWREADY(),
    .S_AXI_WDATA(),
    .S_AXI_WSTRB(),
    .S_AXI_WLAST(),
    .S_AXI_WVALID(),
    .S_AXI_WREADY(),
    .S_AXI_BID(),
    .S_AXI_BRESP(),
    .S_AXI_BVALID(),
    .S_AXI_BREADY(),
    .S_AXI_ARID(),
    .S_AXI_ARADDR(),
    .S_AXI_ARLEN(),
    .S_AXI_ARSIZE(),
    .S_AXI_ARBURST(),
    .S_AXI_ARVALID(),
    .S_AXI_ARREADY(),
    .S_AXI_RID(),
    .S_AXI_RDATA(),
    .S_AXI_RRESP(),
    .S_AXI_RLAST(),
    .S_AXI_RVALID(),
    .S_AXI_RREADY(),
    .S_AXI_INJECTSBITERR(),
    .S_AXI_INJECTDBITERR(),
    .S_AXI_SBITERR(),
    .S_AXI_DBITERR(),
    .S_AXI_RDADDRECC()
  );

// synthesis translate_on

endmodule


// gen_m version 2018.01.11
`timescale 1ns/10ps
module  sim_Bisted_S1P64X72
(
        Q,          // data out
        SQ,         // sampled data out
        BistFail,   // result of BIST circuit  (1: Fail, 0: Pass)
        BistFinish, // result of BIST circuit  (1: Finish, 0: idle or testing)
        CLK,        // clock input
        CEN,        // chip enable for read and write operation (active low)
        WEN,        // write enable (active low)
        A,          // address
        D,          // data in
        RESET_B,    // active low reset
        NVIC_RST_B, // global Novelics resetb (should be connected to HW_CFG_SET_RST_B)
        BistMode,   // 1: BIST mode, 0: normal mode
	SCAN_ENABLE, 
        TEST_MODE   // 1: SRAM is in by-pass mode, 0: Normal mode
);

output  [71:0]       Q;
output  [71:0]       SQ;
output          BistFail;
output          BistFinish;

input           CLK;
input           CEN;
input             WEN;
input   [5:0]        A;
input   [71:0]       D;
input           RESET_B;
input           NVIC_RST_B;
input           BistMode;
input		SCAN_ENABLE;
input           TEST_MODE;

reg             WEN_DLY;

wire    BistFail        = 1'b0;
wire    BistFinish      = 1'b0;

wire	[0:0]	WEN_CEN	= WEN | CEN;

reg CEN_TMP;

 wire  [71 : 0] Q_SRC;
 wire  [71 : 0] Q_ORG;
 reg   [71 : 0] BYPASS ;
 wire  [71 : 0] Q = Q_ORG ;
 wire  [71 : 0] SQ = BYPASS; 
 wire  [71:0]  Q_SEL;
 reg             PRE_CE;
 reg     [5:0]   RA_DLY;

  always @(posedge CLK or negedge RESET_B)
  if(~RESET_B)
    BYPASS <= #0.5 0;
  else
    BYPASS <= #0.5 Q_ORG;

assign Q_ORG = WEN_DLY ? Q_SEL : 72'h0;
wire WEN_ANY = &WEN;

always @(posedge CLK or negedge RESET_B)
  if(~RESET_B)
    RA_DLY <= #0.5 0;
  else
    RA_DLY <= #0.5 A;

always @(posedge CLK or negedge RESET_B)
  if(~RESET_B)
    PRE_CE <= #0.5 1'b0;
  else
    PRE_CE <= #0.5 ~CEN;

always @(posedge CLK or negedge RESET_B)
if(~RESET_B)
    WEN_DLY <= #0.5 1'b1;
else
    WEN_DLY <= #0.5 WEN_ANY | CEN;

always @(A or RA_DLY or WEN_ANY or CEN or PRE_CE or WEN_DLY)
  CEN_TMP = (((A==RA_DLY)&&PRE_CE)|CEN)&&(WEN_ANY|CEN)&&WEN_DLY;

//new added by dh.feng
reg         HOLD;
reg [71:0]  Q_REG;

always @(posedge CLK or negedge RESET_B)
if (!RESET_B)
  HOLD <= #0.5 1'b1;
else
  HOLD <= #0.5 CEN_TMP;

always @(posedge CLK)
if (!HOLD)
  Q_REG <= #0.5 Q_SRC;

assign Q_SEL = HOLD ? Q_REG : Q_SRC;

s1p_ram64x72 U_s1p_ram64x72        (
        .clka   (CLK),
        .dina   (D),
        .addra  (A),
        .wea    ( ~(WEN|CEN_TMP|CEN) ),
        .ena    (1'b1),
        .douta  (Q_SRC)
        );


endmodule

`ifdef   s1p_ram64x72_DEFINED
`else // s1p_ram64x72_DEFINED
`define  s1p_ram64x72_DEFINED

/*******************************************************************************
*     This file is owned and controlled by Xilinx and must be used solely      *
*     for design, simulation, implementation and creation of design files      *
*     limited to Xilinx devices or technologies. Use with non-Xilinx           *
*     devices or technologies is expressly prohibited and immediately          *
*     terminates your license.                                                 *
*                                                                              *
*     XILINX IS PROVIDING THIS DESIGN, CODE, OR INFORMATION "AS IS" SOLELY     *
*     FOR USE IN DEVELOPING PROGRAMS AND SOLUTIONS FOR XILINX DEVICES.  BY     *
*     PROVIDING THIS DESIGN, CODE, OR INFORMATION AS ONE POSSIBLE              *
*     IMPLEMENTATION OF THIS FEATURE, APPLICATION OR STANDARD, XILINX IS       *
*     MAKING NO REPRESENTATION THAT THIS IMPLEMENTATION IS FREE FROM ANY       *
*     CLAIMS OF INFRINGEMENT, AND YOU ARE RESPONSIBLE FOR OBTAINING ANY        *
*     RIGHTS YOU MAY REQUIRE FOR YOUR IMPLEMENTATION.  XILINX EXPRESSLY        *
*     DISCLAIMS ANY WARRANTY WHATSOEVER WITH RESPECT TO THE ADEQUACY OF THE    *
*     IMPLEMENTATION, INCLUDING BUT NOT LIMITED TO ANY WARRANTIES OR           *
*     REPRESENTATIONS THAT THIS IMPLEMENTATION IS FREE FROM CLAIMS OF          *
*     INFRINGEMENT, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A    *
*     PARTICULAR PURPOSE.                                                      *
*                                                                              *
*     Xilinx products are not intended for use in life support appliances,     *
*     devices, or systems.  Use in such applications are expressly             *
*     prohibited.                                                              *
*                                                                              *
*     (c) Copyright 1995-2018 Xilinx, Inc.                                     *
*     All rights reserved.                                                     *
*******************************************************************************/
// You must compile the wrapper file s1p_ram64x72.v when simulating
// the core, s1p_ram64x72. When compiling the wrapper file, be sure to
// reference the XilinxCoreLib Verilog simulation library. For detailed
// instructions, please refer to the "CORE Generator Help".

// The synthesis directives "translate_off/translate_on" specified below are
// supported by Xilinx, Mentor Graphics and Synplicity synthesis
// tools. Ensure they are correct for your synthesis tool(s).

`timescale 1ns/1ps

module s1p_ram64x72(
  clka,
  ena,
  wea,
  addra,
  dina,
  douta
);

input clka;
input ena;
input [0 : 0] wea;
input [5 : 0] addra;
input [71 : 0] dina;
output [71 : 0] douta;

// synthesis translate_off

  BLK_MEM_GEN_V7_3 #(
    .C_ADDRA_WIDTH(6),
    .C_ADDRB_WIDTH(6),
    .C_ALGORITHM(1),
    .C_AXI_ID_WIDTH(4),
    .C_AXI_SLAVE_TYPE(0),
    .C_AXI_TYPE(1),
    .C_BYTE_SIZE(9),
    .C_COMMON_CLK(0),
    .C_DEFAULT_DATA("X"),
    .C_DISABLE_WARN_BHV_COLL(0),
    .C_DISABLE_WARN_BHV_RANGE(0),
    .C_ENABLE_32BIT_ADDRESS(0),
    .C_FAMILY("zynq"),
    .C_HAS_AXI_ID(0),
    .C_HAS_ENA(1),
    .C_HAS_ENB(0),
    .C_HAS_INJECTERR(0),
    .C_HAS_MEM_OUTPUT_REGS_A(0),
    .C_HAS_MEM_OUTPUT_REGS_B(0),
    .C_HAS_MUX_OUTPUT_REGS_A(0),
    .C_HAS_MUX_OUTPUT_REGS_B(0),
    .C_HAS_REGCEA(0),
    .C_HAS_REGCEB(0),
    .C_HAS_RSTA(0),
    .C_HAS_RSTB(0),
    .C_HAS_SOFTECC_INPUT_REGS_A(0),
    .C_HAS_SOFTECC_OUTPUT_REGS_B(0),
    .C_INIT_FILE("BlankString"),
    .C_INIT_FILE_NAME("no_coe_file_loaded"),
    .C_INITA_VAL("0"),
    .C_INITB_VAL("0"),
    .C_INTERFACE_TYPE(0),
    .C_LOAD_INIT_FILE(0),
    .C_MEM_TYPE(0),
    .C_MUX_PIPELINE_STAGES(0),
    .C_PRIM_TYPE(1),
    .C_READ_DEPTH_A(64),
    .C_READ_DEPTH_B(64),
    .C_READ_WIDTH_A(72),
    .C_READ_WIDTH_B(72),
    .C_RST_PRIORITY_A("CE"),
    .C_RST_PRIORITY_B("CE"),
    .C_RST_TYPE("SYNC"),
    .C_RSTRAM_A(0),
    .C_RSTRAM_B(0),
    .C_SIM_COLLISION_CHECK("GENERATE_X_ONLY"),
    .C_USE_BRAM_BLOCK(0),
    .C_USE_BYTE_WEA(0),
    .C_USE_BYTE_WEB(0),
    .C_USE_DEFAULT_DATA(1),
    .C_USE_ECC(0),
    .C_USE_SOFTECC(0),
    .C_WEA_WIDTH(1),
    .C_WEB_WIDTH(1),
    .C_WRITE_DEPTH_A(64),
    .C_WRITE_DEPTH_B(64),
    .C_WRITE_MODE_A("READ_FIRST"),
    .C_WRITE_MODE_B("WRITE_FIRST"),
    .C_WRITE_WIDTH_A(72),
    .C_WRITE_WIDTH_B(72),
    .C_XDEVICEFAMILY("zynq")
  )
  inst (
    .CLKA(clka),
    .ENA(ena),
    .WEA(wea),
    .ADDRA(addra),
    .DINA(dina),
    .DOUTA(douta),
    .RSTA(),
    .REGCEA(),
    .CLKB(),
    .RSTB(),
    .ENB(),
    .REGCEB(),
    .WEB(),
    .ADDRB(),
    .DINB(),
    .DOUTB(),
    .INJECTSBITERR(),
    .INJECTDBITERR(),
    .SBITERR(),
    .DBITERR(),
    .RDADDRECC(),
    .S_ACLK(),
    .S_ARESETN(),
    .S_AXI_AWID(),
    .S_AXI_AWADDR(),
    .S_AXI_AWLEN(),
    .S_AXI_AWSIZE(),
    .S_AXI_AWBURST(),
    .S_AXI_AWVALID(),
    .S_AXI_AWREADY(),
    .S_AXI_WDATA(),
    .S_AXI_WSTRB(),
    .S_AXI_WLAST(),
    .S_AXI_WVALID(),
    .S_AXI_WREADY(),
    .S_AXI_BID(),
    .S_AXI_BRESP(),
    .S_AXI_BVALID(),
    .S_AXI_BREADY(),
    .S_AXI_ARID(),
    .S_AXI_ARADDR(),
    .S_AXI_ARLEN(),
    .S_AXI_ARSIZE(),
    .S_AXI_ARBURST(),
    .S_AXI_ARVALID(),
    .S_AXI_ARREADY(),
    .S_AXI_RID(),
    .S_AXI_RDATA(),
    .S_AXI_RRESP(),
    .S_AXI_RLAST(),
    .S_AXI_RVALID(),
    .S_AXI_RREADY(),
    .S_AXI_INJECTSBITERR(),
    .S_AXI_INJECTDBITERR(),
    .S_AXI_SBITERR(),
    .S_AXI_DBITERR(),
    .S_AXI_RDADDRECC()
  );

// synthesis translate_on

endmodule
`endif // s1p_ram64x72_DEFINED
// gen_m version 2018.01.11
`timescale 1ns/10ps
module  sim_Bisted_S2P128X64
(
        Q,              // data out
        SQ,             // sampled data out
        BistFail,       // result of BIST circuit  (1: Fail, 0: Pass)
        BistFinish,     // result of BIST circuit  (1: Finish, 0: idle or testing)
        CLK,            // clock input
        CLKX2,          // clock x 2 input for ALTERA cycle-share-dual-port memory
        RCEN,           // chip enable for read and write operation  (active low)
        RA,             // read address
        WEN,            // write enable  (active low)
        WA,             // write address
        D,              // data in
        RESET_B,        // active low reset
        NVIC_RST_B, // global Novelics resetb (should be connected to HW_CFG_SET_RST_B)
        BistMode,       // 1: BIST mode, 0: normal mode
	SCAN_ENABLE, 
        TEST_MODE       // 1: SRAM is in by-pass mode, 0: Normal mode
);

output  [63:0]       Q;
output  [63:0]       SQ;
output          BistFail;
output          BistFinish;

input           CLK;
input           CLKX2;
input           RCEN;
input   [6:0]        RA;
input             WEN;
input   [6:0]        WA;
input   [63:0]       D;
input           RESET_B;
input           NVIC_RST_B;
input           BistMode;
input		SCAN_ENABLE;
input           TEST_MODE;

wire    BistFail        = 1'b0;
wire    BistFinish      = 1'b0;

wire [0:0] WEN_RCEN = WEN | RCEN;

reg             CENA_TMP;
wire            CEN_TMP = CENA_TMP;

   wire  [63 : 0] Q_ORG ;
   reg   [63 : 0] BYPASS ;
   wire  [63 : 0] Q_MX ;
   wire  [63 : 0] Q = Q_MX;
   wire  [63 : 0] SQ = BYPASS; 
  always @(posedge CLK or negedge RESET_B)
    if(~RESET_B)
      BYPASS <= #0.5 0;
    else
      BYPASS <= #0.5 Q;

reg             WENB_DLY;
reg             PRE_CEA;
always @(posedge CLK or negedge RESET_B)
  if(~RESET_B)
    PRE_CEA<=#0.5 1'b0;
  else
    PRE_CEA<=#0.5 ~RCEN;

reg     [6:0]  RA_DLY;
always @(posedge CLK or negedge RESET_B)
  if(~RESET_B)
    RA_DLY<=#0.5 0;
  else
    RA_DLY<=#0.5 RA;

wire WEN_ANY = &WEN_RCEN;

always @(posedge CLK or negedge RESET_B)
  if(~RESET_B)
    WENB_DLY <= #0.5 1'b1;
  else
    WENB_DLY <= #0.5 WEN_ANY | RCEN;

always @( RA_DLY or RA or RCEN or PRE_CEA or WEN_ANY or WENB_DLY) begin
  CENA_TMP=(((RA==RA_DLY)&&PRE_CEA)|RCEN)&&(WEN_ANY|RCEN)&&WENB_DLY;
end
wire WRITE_BF_READ = (RA == WA) & !WEN_ANY & !RCEN;
reg  WRITE_BF_READ_FLAG;

always @(posedge CLK or negedge RESET_B)
  if(~RESET_B)
    WRITE_BF_READ_FLAG <= #0.5 1'b0;
  else if(WRITE_BF_READ)
    WRITE_BF_READ_FLAG <= #0.5 1'b1;
  else 
    WRITE_BF_READ_FLAG <= #0.5 1'b0;

reg  [63 : 0] WRITE_BF_READ_DATA ;

always @(posedge CLK or negedge RESET_B)
if(~RESET_B)
  WRITE_BF_READ_DATA <= #0.5 0;
else begin
  if(!WEN_RCEN[0])
       WRITE_BF_READ_DATA[63:0] <= #0.5 D[63:0];
  else
       WRITE_BF_READ_DATA[63:0] <= #0.5 64'b0;
end

wire [63:0] Q_SEL;
assign  Q_MX = WRITE_BF_READ_FLAG ? WRITE_BF_READ_DATA : Q_SEL;


reg HOLD;
reg WEN_DLY;
reg [63:0] Q_REG;

assign Q_SEL = HOLD ? Q_REG :Q_ORG;
always @(posedge CLK or negedge RESET_B)
if (~RESET_B)
  WEN_DLY <= #0.5 1'b1;
else
  WEN_DLY <= #0.5 RCEN | (&WEN);
  
always @(posedge CLK or negedge RESET_B)
if (!RESET_B)
  HOLD <= #0.5 1'b1;
else
  HOLD <= #0.5 CENA_TMP;
  
always @(posedge CLK)
if (!HOLD)
  Q_REG <= #0.5 Q_ORG;

s2p_ram128x64 U_s2p_ram128x64        (
        .clka   (CLK),
        .dina   (D),
        .addra  (WA),
        .wea    ( ~(WEN|RCEN) ),
        .ena    (1'b1),
        .enb    (1'b1),
        .clkb   (CLK),
        .addrb  (RA),
        .doutb  (Q_ORG)
        );


endmodule

`ifdef   s2p_ram128x64_DEFINED
`else // s2p_ram128x64_DEFINED
`define  s2p_ram128x64_DEFINED

/*******************************************************************************
*     This file is owned and controlled by Xilinx and must be used solely      *
*     for design, simulation, implementation and creation of design files      *
*     limited to Xilinx devices or technologies. Use with non-Xilinx           *
*     devices or technologies is expressly prohibited and immediately          *
*     terminates your license.                                                 *
*                                                                              *
*     XILINX IS PROVIDING THIS DESIGN, CODE, OR INFORMATION "AS IS" SOLELY     *
*     FOR USE IN DEVELOPING PROGRAMS AND SOLUTIONS FOR XILINX DEVICES.  BY     *
*     PROVIDING THIS DESIGN, CODE, OR INFORMATION AS ONE POSSIBLE              *
*     IMPLEMENTATION OF THIS FEATURE, APPLICATION OR STANDARD, XILINX IS       *
*     MAKING NO REPRESENTATION THAT THIS IMPLEMENTATION IS FREE FROM ANY       *
*     CLAIMS OF INFRINGEMENT, AND YOU ARE RESPONSIBLE FOR OBTAINING ANY        *
*     RIGHTS YOU MAY REQUIRE FOR YOUR IMPLEMENTATION.  XILINX EXPRESSLY        *
*     DISCLAIMS ANY WARRANTY WHATSOEVER WITH RESPECT TO THE ADEQUACY OF THE    *
*     IMPLEMENTATION, INCLUDING BUT NOT LIMITED TO ANY WARRANTIES OR           *
*     REPRESENTATIONS THAT THIS IMPLEMENTATION IS FREE FROM CLAIMS OF          *
*     INFRINGEMENT, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A    *
*     PARTICULAR PURPOSE.                                                      *
*                                                                              *
*     Xilinx products are not intended for use in life support appliances,     *
*     devices, or systems.  Use in such applications are expressly             *
*     prohibited.                                                              *
*                                                                              *
*     (c) Copyright 1995-2018 Xilinx, Inc.                                     *
*     All rights reserved.                                                     *
*******************************************************************************/
// You must compile the wrapper file s2p_ram128x64.v when simulating
// the core, s2p_ram128x64. When compiling the wrapper file, be sure to
// reference the XilinxCoreLib Verilog simulation library. For detailed
// instructions, please refer to the "CORE Generator Help".

// The synthesis directives "translate_off/translate_on" specified below are
// supported by Xilinx, Mentor Graphics and Synplicity synthesis
// tools. Ensure they are correct for your synthesis tool(s).

`timescale 1ns/1ps

module s2p_ram128x64(
  clka,
  ena,
  wea,
  addra,
  dina,
  clkb,
  enb,
  addrb,
  doutb
);

input clka;
input ena;
input [0 : 0] wea;
input [6 : 0] addra;
input [63 : 0] dina;
input clkb;
input enb;
input [6 : 0] addrb;
output [63 : 0] doutb;

// synthesis translate_off

  BLK_MEM_GEN_V7_3 #(
    .C_ADDRA_WIDTH(7),
    .C_ADDRB_WIDTH(7),
    .C_ALGORITHM(1),
    .C_AXI_ID_WIDTH(4),
    .C_AXI_SLAVE_TYPE(0),
    .C_AXI_TYPE(1),
    .C_BYTE_SIZE(9),
    .C_COMMON_CLK(0),
    .C_DEFAULT_DATA("X"),
    .C_DISABLE_WARN_BHV_COLL(0),
    .C_DISABLE_WARN_BHV_RANGE(0),
    .C_ENABLE_32BIT_ADDRESS(0),
    .C_FAMILY("zynq"),
    .C_HAS_AXI_ID(0),
    .C_HAS_ENA(1),
    .C_HAS_ENB(1),
    .C_HAS_INJECTERR(0),
    .C_HAS_MEM_OUTPUT_REGS_A(0),
    .C_HAS_MEM_OUTPUT_REGS_B(0),
    .C_HAS_MUX_OUTPUT_REGS_A(0),
    .C_HAS_MUX_OUTPUT_REGS_B(0),
    .C_HAS_REGCEA(0),
    .C_HAS_REGCEB(0),
    .C_HAS_RSTA(0),
    .C_HAS_RSTB(0),
    .C_HAS_SOFTECC_INPUT_REGS_A(0),
    .C_HAS_SOFTECC_OUTPUT_REGS_B(0),
    .C_INIT_FILE("BlankString"),
    .C_INIT_FILE_NAME("no_coe_file_loaded"),
    .C_INITA_VAL("0"),
    .C_INITB_VAL("0"),
    .C_INTERFACE_TYPE(0),
    .C_LOAD_INIT_FILE(0),
    .C_MEM_TYPE(1),
    .C_MUX_PIPELINE_STAGES(0),
    .C_PRIM_TYPE(1),
    .C_READ_DEPTH_A(128),
    .C_READ_DEPTH_B(128),
    .C_READ_WIDTH_A(64),
    .C_READ_WIDTH_B(64),
    .C_RST_PRIORITY_A("CE"),
    .C_RST_PRIORITY_B("CE"),
    .C_RST_TYPE("SYNC"),
    .C_RSTRAM_A(0),
    .C_RSTRAM_B(0),
    .C_SIM_COLLISION_CHECK("GENERATE_X_ONLY"),
    .C_USE_BRAM_BLOCK(0),
    .C_USE_BYTE_WEA(0),
    .C_USE_BYTE_WEB(0),
    .C_USE_DEFAULT_DATA(1),
    .C_USE_ECC(0),
    .C_USE_SOFTECC(0),
    .C_WEA_WIDTH(1),
    .C_WEB_WIDTH(1),
    .C_WRITE_DEPTH_A(128),
    .C_WRITE_DEPTH_B(128),
    .C_WRITE_MODE_A("WRITE_FIRST"),
    .C_WRITE_MODE_B("WRITE_FIRST"),
    .C_WRITE_WIDTH_A(64),
    .C_WRITE_WIDTH_B(64),
    .C_XDEVICEFAMILY("zynq")
  )
  inst (
    .CLKA(clka),
    .ENA(ena),
    .WEA(wea),
    .ADDRA(addra),
    .DINA(dina),
    .CLKB(clkb),
    .ENB(enb),
    .ADDRB(addrb),
    .DOUTB(doutb),
    .RSTA(),
    .REGCEA(),
    .DOUTA(),
    .RSTB(),
    .REGCEB(),
    .WEB(),
    .DINB(),
    .INJECTSBITERR(),
    .INJECTDBITERR(),
    .SBITERR(),
    .DBITERR(),
    .RDADDRECC(),
    .S_ACLK(),
    .S_ARESETN(),
    .S_AXI_AWID(),
    .S_AXI_AWADDR(),
    .S_AXI_AWLEN(),
    .S_AXI_AWSIZE(),
    .S_AXI_AWBURST(),
    .S_AXI_AWVALID(),
    .S_AXI_AWREADY(),
    .S_AXI_WDATA(),
    .S_AXI_WSTRB(),
    .S_AXI_WLAST(),
    .S_AXI_WVALID(),
    .S_AXI_WREADY(),
    .S_AXI_BID(),
    .S_AXI_BRESP(),
    .S_AXI_BVALID(),
    .S_AXI_BREADY(),
    .S_AXI_ARID(),
    .S_AXI_ARADDR(),
    .S_AXI_ARLEN(),
    .S_AXI_ARSIZE(),
    .S_AXI_ARBURST(),
    .S_AXI_ARVALID(),
    .S_AXI_ARREADY(),
    .S_AXI_RID(),
    .S_AXI_RDATA(),
    .S_AXI_RRESP(),
    .S_AXI_RLAST(),
    .S_AXI_RVALID(),
    .S_AXI_RREADY(),
    .S_AXI_INJECTSBITERR(),
    .S_AXI_INJECTDBITERR(),
    .S_AXI_SBITERR(),
    .S_AXI_DBITERR(),
    .S_AXI_RDADDRECC()
  );

// synthesis translate_on

endmodule
`endif // s2p_ram128x64_DEFINED

// gen_m version 2018.01.11
`timescale 1ns/10ps
module  sim_Bisted_S2P64X64
(
        Q,              // data out
        SQ,             // sampled data out
        BistFail,       // result of BIST circuit  (1: Fail, 0: Pass)
        BistFinish,     // result of BIST circuit  (1: Finish, 0: idle or testing)
        CLK,            // clock input
        CLKX2,          // clock x 2 input for ALTERA cycle-share-dual-port memory
        RCEN,           // chip enable for read and write operation  (active low)
        RA,             // read address
        WEN,            // write enable  (active low)
        WA,             // write address
        D,              // data in
        RESET_B,        // active low reset
        NVIC_RST_B, // global Novelics resetb (should be connected to HW_CFG_SET_RST_B)
        BistMode,       // 1: BIST mode, 0: normal mode
	SCAN_ENABLE, 
        TEST_MODE       // 1: SRAM is in by-pass mode, 0: Normal mode
);

output  [63:0]       Q;
output  [63:0]       SQ;
output          BistFail;
output          BistFinish;

input           CLK;
input           CLKX2;
input           RCEN;
input   [5:0]        RA;
input             WEN;
input   [5:0]        WA;
input   [63:0]       D;
input           RESET_B;
input           NVIC_RST_B;
input           BistMode;
input		SCAN_ENABLE;
input           TEST_MODE;

wire    BistFail        = 1'b0;
wire    BistFinish      = 1'b0;

wire [0:0] WEN_RCEN = WEN | RCEN;

reg             CENA_TMP;
wire            CEN_TMP = CENA_TMP;

   wire  [63 : 0] Q_ORG ;
   reg   [63 : 0] BYPASS ;
   wire  [63 : 0] Q_MX ;
   wire  [63 : 0] Q = Q_MX;
   wire  [63 : 0] SQ = BYPASS; 
  always @(posedge CLK or negedge RESET_B)
    if(~RESET_B)
      BYPASS <= #0.5 0;
    else
      BYPASS <= #0.5 Q;

reg             WENB_DLY;
reg             PRE_CEA;
always @(posedge CLK or negedge RESET_B)
  if(~RESET_B)
    PRE_CEA<=#0.5 1'b0;
  else
    PRE_CEA<=#0.5 ~RCEN;

reg     [5:0]  RA_DLY;
always @(posedge CLK or negedge RESET_B)
  if(~RESET_B)
    RA_DLY<=#0.5 0;
  else
    RA_DLY<=#0.5 RA;

wire WEN_ANY = &WEN_RCEN;

always @(posedge CLK or negedge RESET_B)
  if(~RESET_B)
    WENB_DLY <= #0.5 1'b1;
  else
    WENB_DLY <= #0.5 WEN_ANY | RCEN;

always @( RA_DLY or RA or RCEN or PRE_CEA or WEN_ANY or WENB_DLY) begin
  CENA_TMP=(((RA==RA_DLY)&&PRE_CEA)|RCEN)&&(WEN_ANY|RCEN)&&WENB_DLY;
end
wire WRITE_BF_READ = (RA == WA) & !WEN_ANY & !RCEN;
reg  WRITE_BF_READ_FLAG;

always @(posedge CLK or negedge RESET_B)
  if(~RESET_B)
    WRITE_BF_READ_FLAG <= #0.5 1'b0;
  else if(WRITE_BF_READ)
    WRITE_BF_READ_FLAG <= #0.5 1'b1;
  else 
    WRITE_BF_READ_FLAG <= #0.5 1'b0;

reg  [63 : 0] WRITE_BF_READ_DATA ;

always @(posedge CLK or negedge RESET_B)
if(~RESET_B)
  WRITE_BF_READ_DATA <= #0.5 0;
else begin
  if(!WEN_RCEN[0])
       WRITE_BF_READ_DATA[63:0] <= #0.5 D[63:0];
  else
       WRITE_BF_READ_DATA[63:0] <= #0.5 64'b0;
end

wire [63:0] Q_SEL;
assign  Q_MX = WRITE_BF_READ_FLAG ? WRITE_BF_READ_DATA : Q_SEL;


reg HOLD;
reg WEN_DLY;
reg [63:0] Q_REG;

assign Q_SEL = HOLD ? Q_REG :Q_ORG;
always @(posedge CLK or negedge RESET_B)
if (~RESET_B)
  WEN_DLY <= #0.5 1'b1;
else
  WEN_DLY <= #0.5 RCEN | (&WEN);
  
always @(posedge CLK or negedge RESET_B)
if (!RESET_B)
  HOLD <= #0.5 1'b1;
else
  HOLD <= #0.5 CENA_TMP;
  
always @(posedge CLK)
if (!HOLD)
  Q_REG <= #0.5 Q_ORG;

s2p_ram64x64 U_s2p_ram64x64        (
        .clka   (CLK),
        .dina   (D),
        .addra  (WA),
        .wea    ( ~(WEN|RCEN) ),
        .ena    (1'b1),
        .enb    (1'b1),
        .clkb   (CLK),
        .addrb  (RA),
        .doutb  (Q_ORG)
        );


endmodule

`ifdef   s2p_ram64x64_DEFINED
`else // s2p_ram64x64_DEFINED
`define  s2p_ram64x64_DEFINED

/*******************************************************************************
*     This file is owned and controlled by Xilinx and must be used solely      *
*     for design, simulation, implementation and creation of design files      *
*     limited to Xilinx devices or technologies. Use with non-Xilinx           *
*     devices or technologies is expressly prohibited and immediately          *
*     terminates your license.                                                 *
*                                                                              *
*     XILINX IS PROVIDING THIS DESIGN, CODE, OR INFORMATION "AS IS" SOLELY     *
*     FOR USE IN DEVELOPING PROGRAMS AND SOLUTIONS FOR XILINX DEVICES.  BY     *
*     PROVIDING THIS DESIGN, CODE, OR INFORMATION AS ONE POSSIBLE              *
*     IMPLEMENTATION OF THIS FEATURE, APPLICATION OR STANDARD, XILINX IS       *
*     MAKING NO REPRESENTATION THAT THIS IMPLEMENTATION IS FREE FROM ANY       *
*     CLAIMS OF INFRINGEMENT, AND YOU ARE RESPONSIBLE FOR OBTAINING ANY        *
*     RIGHTS YOU MAY REQUIRE FOR YOUR IMPLEMENTATION.  XILINX EXPRESSLY        *
*     DISCLAIMS ANY WARRANTY WHATSOEVER WITH RESPECT TO THE ADEQUACY OF THE    *
*     IMPLEMENTATION, INCLUDING BUT NOT LIMITED TO ANY WARRANTIES OR           *
*     REPRESENTATIONS THAT THIS IMPLEMENTATION IS FREE FROM CLAIMS OF          *
*     INFRINGEMENT, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A    *
*     PARTICULAR PURPOSE.                                                      *
*                                                                              *
*     Xilinx products are not intended for use in life support appliances,     *
*     devices, or systems.  Use in such applications are expressly             *
*     prohibited.                                                              *
*                                                                              *
*     (c) Copyright 1995-2018 Xilinx, Inc.                                     *
*     All rights reserved.                                                     *
*******************************************************************************/
// You must compile the wrapper file s2p_ram64x64.v when simulating
// the core, s2p_ram64x64. When compiling the wrapper file, be sure to
// reference the XilinxCoreLib Verilog simulation library. For detailed
// instructions, please refer to the "CORE Generator Help".

// The synthesis directives "translate_off/translate_on" specified below are
// supported by Xilinx, Mentor Graphics and Synplicity synthesis
// tools. Ensure they are correct for your synthesis tool(s).

`timescale 1ns/1ps

module s2p_ram64x64(
  clka,
  ena,
  wea,
  addra,
  dina,
  clkb,
  enb,
  addrb,
  doutb
);

input clka;
input ena;
input [0 : 0] wea;
input [5 : 0] addra;
input [63 : 0] dina;
input clkb;
input enb;
input [5 : 0] addrb;
output [63 : 0] doutb;

// synthesis translate_off

  BLK_MEM_GEN_V7_3 #(
    .C_ADDRA_WIDTH(6),
    .C_ADDRB_WIDTH(6),
    .C_ALGORITHM(1),
    .C_AXI_ID_WIDTH(4),
    .C_AXI_SLAVE_TYPE(0),
    .C_AXI_TYPE(1),
    .C_BYTE_SIZE(9),
    .C_COMMON_CLK(0),
    .C_DEFAULT_DATA("X"),
    .C_DISABLE_WARN_BHV_COLL(0),
    .C_DISABLE_WARN_BHV_RANGE(0),
    .C_ENABLE_32BIT_ADDRESS(0),
    .C_FAMILY("zynq"),
    .C_HAS_AXI_ID(0),
    .C_HAS_ENA(1),
    .C_HAS_ENB(1),
    .C_HAS_INJECTERR(0),
    .C_HAS_MEM_OUTPUT_REGS_A(0),
    .C_HAS_MEM_OUTPUT_REGS_B(0),
    .C_HAS_MUX_OUTPUT_REGS_A(0),
    .C_HAS_MUX_OUTPUT_REGS_B(0),
    .C_HAS_REGCEA(0),
    .C_HAS_REGCEB(0),
    .C_HAS_RSTA(0),
    .C_HAS_RSTB(0),
    .C_HAS_SOFTECC_INPUT_REGS_A(0),
    .C_HAS_SOFTECC_OUTPUT_REGS_B(0),
    .C_INIT_FILE("BlankString"),
    .C_INIT_FILE_NAME("no_coe_file_loaded"),
    .C_INITA_VAL("0"),
    .C_INITB_VAL("0"),
    .C_INTERFACE_TYPE(0),
    .C_LOAD_INIT_FILE(0),
    .C_MEM_TYPE(1),
    .C_MUX_PIPELINE_STAGES(0),
    .C_PRIM_TYPE(1),
    .C_READ_DEPTH_A(64),
    .C_READ_DEPTH_B(64),
    .C_READ_WIDTH_A(64),
    .C_READ_WIDTH_B(64),
    .C_RST_PRIORITY_A("CE"),
    .C_RST_PRIORITY_B("CE"),
    .C_RST_TYPE("SYNC"),
    .C_RSTRAM_A(0),
    .C_RSTRAM_B(0),
    .C_SIM_COLLISION_CHECK("GENERATE_X_ONLY"),
    .C_USE_BRAM_BLOCK(0),
    .C_USE_BYTE_WEA(0),
    .C_USE_BYTE_WEB(0),
    .C_USE_DEFAULT_DATA(1),
    .C_USE_ECC(0),
    .C_USE_SOFTECC(0),
    .C_WEA_WIDTH(1),
    .C_WEB_WIDTH(1),
    .C_WRITE_DEPTH_A(64),
    .C_WRITE_DEPTH_B(64),
    .C_WRITE_MODE_A("WRITE_FIRST"),
    .C_WRITE_MODE_B("WRITE_FIRST"),
    .C_WRITE_WIDTH_A(64),
    .C_WRITE_WIDTH_B(64),
    .C_XDEVICEFAMILY("zynq")
  )
  inst (
    .CLKA(clka),
    .ENA(ena),
    .WEA(wea),
    .ADDRA(addra),
    .DINA(dina),
    .CLKB(clkb),
    .ENB(enb),
    .ADDRB(addrb),
    .DOUTB(doutb),
    .RSTA(),
    .REGCEA(),
    .DOUTA(),
    .RSTB(),
    .REGCEB(),
    .WEB(),
    .DINB(),
    .INJECTSBITERR(),
    .INJECTDBITERR(),
    .SBITERR(),
    .DBITERR(),
    .RDADDRECC(),
    .S_ACLK(),
    .S_ARESETN(),
    .S_AXI_AWID(),
    .S_AXI_AWADDR(),
    .S_AXI_AWLEN(),
    .S_AXI_AWSIZE(),
    .S_AXI_AWBURST(),
    .S_AXI_AWVALID(),
    .S_AXI_AWREADY(),
    .S_AXI_WDATA(),
    .S_AXI_WSTRB(),
    .S_AXI_WLAST(),
    .S_AXI_WVALID(),
    .S_AXI_WREADY(),
    .S_AXI_BID(),
    .S_AXI_BRESP(),
    .S_AXI_BVALID(),
    .S_AXI_BREADY(),
    .S_AXI_ARID(),
    .S_AXI_ARADDR(),
    .S_AXI_ARLEN(),
    .S_AXI_ARSIZE(),
    .S_AXI_ARBURST(),
    .S_AXI_ARVALID(),
    .S_AXI_ARREADY(),
    .S_AXI_RID(),
    .S_AXI_RDATA(),
    .S_AXI_RRESP(),
    .S_AXI_RLAST(),
    .S_AXI_RVALID(),
    .S_AXI_RREADY(),
    .S_AXI_INJECTSBITERR(),
    .S_AXI_INJECTDBITERR(),
    .S_AXI_SBITERR(),
    .S_AXI_DBITERR(),
    .S_AXI_RDADDRECC()
  );

// synthesis translate_on

endmodule
`endif // s2p_ram64x64_DEFINED
// gen_m version 2018.01.11
`timescale 1ns/10ps
module  sim_Bisted_S2P64X72
(
        Q,              // data out
        SQ,             // sampled data out
        BistFail,       // result of BIST circuit  (1: Fail, 0: Pass)
        BistFinish,     // result of BIST circuit  (1: Finish, 0: idle or testing)
        CLK,            // clock input
        CLKX2,          // clock x 2 input for ALTERA cycle-share-dual-port memory
        RCEN,           // chip enable for read and write operation  (active low)
        RA,             // read address
        WEN,            // write enable  (active low)
        WA,             // write address
        D,              // data in
        RESET_B,        // active low reset
        NVIC_RST_B, // global Novelics resetb (should be connected to HW_CFG_SET_RST_B)
        BistMode,       // 1: BIST mode, 0: normal mode
	SCAN_ENABLE, 
        TEST_MODE       // 1: SRAM is in by-pass mode, 0: Normal mode
);

output  [71:0]       Q;
output  [71:0]       SQ;
output          BistFail;
output          BistFinish;

input           CLK;
input           CLKX2;
input           RCEN;
input   [5:0]        RA;
input             WEN;
input   [5:0]        WA;
input   [71:0]       D;
input           RESET_B;
input           NVIC_RST_B;
input           BistMode;
input		SCAN_ENABLE;
input           TEST_MODE;

wire    BistFail        = 1'b0;
wire    BistFinish      = 1'b0;

wire [0:0] WEN_RCEN = WEN | RCEN;

reg             CENA_TMP;
wire            CEN_TMP = CENA_TMP;

   wire  [71 : 0] Q_ORG ;
   reg   [71 : 0] BYPASS ;
   wire  [71 : 0] Q_MX ;
   wire  [71 : 0] Q = Q_MX;
   wire  [71 : 0] SQ = BYPASS; 
  always @(posedge CLK or negedge RESET_B)
    if(~RESET_B)
      BYPASS <= #0.5 0;
    else
      BYPASS <= #0.5 Q;

reg             WENB_DLY;
reg             PRE_CEA;
always @(posedge CLK or negedge RESET_B)
  if(~RESET_B)
    PRE_CEA<=#0.5 1'b0;
  else
    PRE_CEA<=#0.5 ~RCEN;

reg     [5:0]  RA_DLY;
always @(posedge CLK or negedge RESET_B)
  if(~RESET_B)
    RA_DLY<=#0.5 0;
  else
    RA_DLY<=#0.5 RA;

wire WEN_ANY = &WEN_RCEN;

always @(posedge CLK or negedge RESET_B)
  if(~RESET_B)
    WENB_DLY <= #0.5 1'b1;
  else
    WENB_DLY <= #0.5 WEN_ANY | RCEN;

always @( RA_DLY or RA or RCEN or PRE_CEA or WEN_ANY or WENB_DLY) begin
  CENA_TMP=(((RA==RA_DLY)&&PRE_CEA)|RCEN)&&(WEN_ANY|RCEN)&&WENB_DLY;
end
wire WRITE_BF_READ = (RA == WA) & !WEN_ANY & !RCEN;
reg  WRITE_BF_READ_FLAG;

always @(posedge CLK or negedge RESET_B)
  if(~RESET_B)
    WRITE_BF_READ_FLAG <= #0.5 1'b0;
  else if(WRITE_BF_READ)
    WRITE_BF_READ_FLAG <= #0.5 1'b1;
  else 
    WRITE_BF_READ_FLAG <= #0.5 1'b0;

reg  [71 : 0] WRITE_BF_READ_DATA ;

always @(posedge CLK or negedge RESET_B)
if(~RESET_B)
  WRITE_BF_READ_DATA <= #0.5 0;
else begin
  if(!WEN_RCEN[0])
       WRITE_BF_READ_DATA[71:0] <= #0.5 D[71:0];
  else
       WRITE_BF_READ_DATA[71:0] <= #0.5 72'b0;
end

wire [71:0] Q_SEL;
assign  Q_MX = WRITE_BF_READ_FLAG ? WRITE_BF_READ_DATA : Q_SEL;


reg HOLD;
reg WEN_DLY;
reg [71:0] Q_REG;

assign Q_SEL = HOLD ? Q_REG :Q_ORG;
always @(posedge CLK or negedge RESET_B)
if (~RESET_B)
  WEN_DLY <= #0.5 1'b1;
else
  WEN_DLY <= #0.5 RCEN | (&WEN);
  
always @(posedge CLK or negedge RESET_B)
if (!RESET_B)
  HOLD <= #0.5 1'b1;
else
  HOLD <= #0.5 CENA_TMP;
  
always @(posedge CLK)
if (!HOLD)
  Q_REG <= #0.5 Q_ORG;

s2p_ram64x72 U_s2p_ram64x72        (
        .clka   (CLK),
        .dina   (D),
        .addra  (WA),
        .wea    ( ~(WEN|RCEN) ),
        .ena    (1'b1),
        .enb    (1'b1),
        .clkb   (CLK),
        .addrb  (RA),
        .doutb  (Q_ORG)
        );


endmodule

`ifdef   s2p_ram64x72_DEFINED
`else // s2p_ram64x72_DEFINED
`define  s2p_ram64x72_DEFINED

/*******************************************************************************
*     This file is owned and controlled by Xilinx and must be used solely      *
*     for design, simulation, implementation and creation of design files      *
*     limited to Xilinx devices or technologies. Use with non-Xilinx           *
*     devices or technologies is expressly prohibited and immediately          *
*     terminates your license.                                                 *
*                                                                              *
*     XILINX IS PROVIDING THIS DESIGN, CODE, OR INFORMATION "AS IS" SOLELY     *
*     FOR USE IN DEVELOPING PROGRAMS AND SOLUTIONS FOR XILINX DEVICES.  BY     *
*     PROVIDING THIS DESIGN, CODE, OR INFORMATION AS ONE POSSIBLE              *
*     IMPLEMENTATION OF THIS FEATURE, APPLICATION OR STANDARD, XILINX IS       *
*     MAKING NO REPRESENTATION THAT THIS IMPLEMENTATION IS FREE FROM ANY       *
*     CLAIMS OF INFRINGEMENT, AND YOU ARE RESPONSIBLE FOR OBTAINING ANY        *
*     RIGHTS YOU MAY REQUIRE FOR YOUR IMPLEMENTATION.  XILINX EXPRESSLY        *
*     DISCLAIMS ANY WARRANTY WHATSOEVER WITH RESPECT TO THE ADEQUACY OF THE    *
*     IMPLEMENTATION, INCLUDING BUT NOT LIMITED TO ANY WARRANTIES OR           *
*     REPRESENTATIONS THAT THIS IMPLEMENTATION IS FREE FROM CLAIMS OF          *
*     INFRINGEMENT, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A    *
*     PARTICULAR PURPOSE.                                                      *
*                                                                              *
*     Xilinx products are not intended for use in life support appliances,     *
*     devices, or systems.  Use in such applications are expressly             *
*     prohibited.                                                              *
*                                                                              *
*     (c) Copyright 1995-2018 Xilinx, Inc.                                     *
*     All rights reserved.                                                     *
*******************************************************************************/
// You must compile the wrapper file s2p_ram64x72.v when simulating
// the core, s2p_ram64x72. When compiling the wrapper file, be sure to
// reference the XilinxCoreLib Verilog simulation library. For detailed
// instructions, please refer to the "CORE Generator Help".

// The synthesis directives "translate_off/translate_on" specified below are
// supported by Xilinx, Mentor Graphics and Synplicity synthesis
// tools. Ensure they are correct for your synthesis tool(s).

`timescale 1ns/1ps

module s2p_ram64x72(
  clka,
  ena,
  wea,
  addra,
  dina,
  clkb,
  enb,
  addrb,
  doutb
);

input clka;
input ena;
input [0 : 0] wea;
input [5 : 0] addra;
input [71 : 0] dina;
input clkb;
input enb;
input [5 : 0] addrb;
output [71 : 0] doutb;

// synthesis translate_off

  BLK_MEM_GEN_V7_3 #(
    .C_ADDRA_WIDTH(6),
    .C_ADDRB_WIDTH(6),
    .C_ALGORITHM(1),
    .C_AXI_ID_WIDTH(4),
    .C_AXI_SLAVE_TYPE(0),
    .C_AXI_TYPE(1),
    .C_BYTE_SIZE(9),
    .C_COMMON_CLK(0),
    .C_DEFAULT_DATA("X"),
    .C_DISABLE_WARN_BHV_COLL(0),
    .C_DISABLE_WARN_BHV_RANGE(0),
    .C_ENABLE_32BIT_ADDRESS(0),
    .C_FAMILY("zynq"),
    .C_HAS_AXI_ID(0),
    .C_HAS_ENA(1),
    .C_HAS_ENB(1),
    .C_HAS_INJECTERR(0),
    .C_HAS_MEM_OUTPUT_REGS_A(0),
    .C_HAS_MEM_OUTPUT_REGS_B(0),
    .C_HAS_MUX_OUTPUT_REGS_A(0),
    .C_HAS_MUX_OUTPUT_REGS_B(0),
    .C_HAS_REGCEA(0),
    .C_HAS_REGCEB(0),
    .C_HAS_RSTA(0),
    .C_HAS_RSTB(0),
    .C_HAS_SOFTECC_INPUT_REGS_A(0),
    .C_HAS_SOFTECC_OUTPUT_REGS_B(0),
    .C_INIT_FILE("BlankString"),
    .C_INIT_FILE_NAME("no_coe_file_loaded"),
    .C_INITA_VAL("0"),
    .C_INITB_VAL("0"),
    .C_INTERFACE_TYPE(0),
    .C_LOAD_INIT_FILE(0),
    .C_MEM_TYPE(1),
    .C_MUX_PIPELINE_STAGES(0),
    .C_PRIM_TYPE(1),
    .C_READ_DEPTH_A(64),
    .C_READ_DEPTH_B(64),
    .C_READ_WIDTH_A(72),
    .C_READ_WIDTH_B(72),
    .C_RST_PRIORITY_A("CE"),
    .C_RST_PRIORITY_B("CE"),
    .C_RST_TYPE("SYNC"),
    .C_RSTRAM_A(0),
    .C_RSTRAM_B(0),
    .C_SIM_COLLISION_CHECK("GENERATE_X_ONLY"),
    .C_USE_BRAM_BLOCK(0),
    .C_USE_BYTE_WEA(0),
    .C_USE_BYTE_WEB(0),
    .C_USE_DEFAULT_DATA(1),
    .C_USE_ECC(0),
    .C_USE_SOFTECC(0),
    .C_WEA_WIDTH(1),
    .C_WEB_WIDTH(1),
    .C_WRITE_DEPTH_A(64),
    .C_WRITE_DEPTH_B(64),
    .C_WRITE_MODE_A("WRITE_FIRST"),
    .C_WRITE_MODE_B("WRITE_FIRST"),
    .C_WRITE_WIDTH_A(72),
    .C_WRITE_WIDTH_B(72),
    .C_XDEVICEFAMILY("zynq")
  )
  inst (
    .CLKA(clka),
    .ENA(ena),
    .WEA(wea),
    .ADDRA(addra),
    .DINA(dina),
    .CLKB(clkb),
    .ENB(enb),
    .ADDRB(addrb),
    .DOUTB(doutb),
    .RSTA(),
    .REGCEA(),
    .DOUTA(),
    .RSTB(),
    .REGCEB(),
    .WEB(),
    .DINB(),
    .INJECTSBITERR(),
    .INJECTDBITERR(),
    .SBITERR(),
    .DBITERR(),
    .RDADDRECC(),
    .S_ACLK(),
    .S_ARESETN(),
    .S_AXI_AWID(),
    .S_AXI_AWADDR(),
    .S_AXI_AWLEN(),
    .S_AXI_AWSIZE(),
    .S_AXI_AWBURST(),
    .S_AXI_AWVALID(),
    .S_AXI_AWREADY(),
    .S_AXI_WDATA(),
    .S_AXI_WSTRB(),
    .S_AXI_WLAST(),
    .S_AXI_WVALID(),
    .S_AXI_WREADY(),
    .S_AXI_BID(),
    .S_AXI_BRESP(),
    .S_AXI_BVALID(),
    .S_AXI_BREADY(),
    .S_AXI_ARID(),
    .S_AXI_ARADDR(),
    .S_AXI_ARLEN(),
    .S_AXI_ARSIZE(),
    .S_AXI_ARBURST(),
    .S_AXI_ARVALID(),
    .S_AXI_ARREADY(),
    .S_AXI_RID(),
    .S_AXI_RDATA(),
    .S_AXI_RRESP(),
    .S_AXI_RLAST(),
    .S_AXI_RVALID(),
    .S_AXI_RREADY(),
    .S_AXI_INJECTSBITERR(),
    .S_AXI_INJECTDBITERR(),
    .S_AXI_SBITERR(),
    .S_AXI_DBITERR(),
    .S_AXI_RDADDRECC()
  );

// synthesis translate_on

endmodule
`endif // s2p_ram64x72_DEFINED
