module fbio_dip_wrap (
  inout  wire [13:0] DIO_1,
  inout  wire [6:0]  DIO_2,
  inout  wire [22:0] DIO_3,

  output wire        F2P_CLK_I,
  input  wire        F2P_CLK_O,
  input  wire        F2P_CLK_OE,
  output wire        P2F_CLK_I,
  input  wire        P2F_CLK_O,
  input  wire        P2F_CLK_OE,
  output wire [35:0] FBIO_PAD_I,
  input  wire [35:0] FBIO_PAD_O,
  input  wire [35:0] FBIO_PAD_OE,
  output wire        FBIO_PAD_RSTB
);

wire [13:0] DIO_1_OE;
wire [13:0] DIO_1_O;
wire [13:0] DIO_1_I;
wire [6:0]  DIO_2_OE;
wire [6:0]  DIO_2_O;
wire [6:0]  DIO_2_I;
wire [22:0] DIO_3_OE;
wire [22:0] DIO_3_O;
wire [22:0] DIO_3_I;

genvar i;
generate 
for (i=0; i<14; i=i+1) begin
  assign DIO_1[i]   = DIO_1_OE[i] ? DIO_1_O[i] : 1'bz;
  assign DIO_1_I[i] = DIO_1[i];
end
endgenerate
generate 
for (i=0; i<7; i=i+1) begin
  assign DIO_2[i]   = DIO_2_OE[i] ? DIO_2_O[i] : 1'bz;
  assign DIO_2_I[i] = DIO_2[i];
end
endgenerate
generate 
for (i=0; i<23; i=i+1) begin
  assign DIO_3[i]   = DIO_3_OE[i] ? DIO_3_O[i] : 1'bz;
  assign DIO_3_I[i] = DIO_3[i];
end
endgenerate

// For connections
// Bchip to FPGA clock
assign DIO_3_OE[14] = P2F_CLK_OE;
assign DIO_3_O[14]  = P2F_CLK_O;
assign P2F_CLK_I = DIO_3_I[14];
//wire locked;
//pll1 u_pll1_0 (
//  .clk_in1 (DIO_3_I[14]),
//  .clk_out1 (P2F_CLK_I),
//  .reset    (1'b0),
//  .locked   (locked)
//);
// FPGA to Bchip clock
assign DIO_1_OE[9] = F2P_CLK_OE;
assign DIO_1_O[9]  = F2P_CLK_O;
assign F2P_CLK_I = DIO_1_I[9];

assign DIO_2_OE[4] = 1'b0;
assign DIO_2_O[4] = 1'b0;
assign FBIO_PAD_RSTB = DIO_2_I[4];

assign DIO_2_OE[5] = 1'b1;
assign DIO_2_O[5]  = 1'b0;  // Interrupt1
assign DIO_3_OE[2] = 1'b1;
assign DIO_3_O[2]  = 1'b0;  // Interrupt0

assign DIO_1_OE[0] = FBIO_PAD_OE[18];
assign DIO_1_O[0]  = FBIO_PAD_O[18];
assign FBIO_PAD_I[18] = DIO_1_I[0];
assign DIO_1_OE[1] = FBIO_PAD_OE[20];
assign DIO_1_O[1]  = FBIO_PAD_O[20];
assign FBIO_PAD_I[20] = DIO_1_I[1];
assign DIO_1_OE[2] = FBIO_PAD_OE[22];
assign DIO_1_O[2]  = FBIO_PAD_O[22];
assign FBIO_PAD_I[22] = DIO_1_I[2];
assign DIO_1_OE[3] = FBIO_PAD_OE[24];
assign DIO_1_O[3]  = FBIO_PAD_O[24];
assign FBIO_PAD_I[24] = DIO_1_I[3];
assign DIO_1_OE[4] = FBIO_PAD_OE[26];
assign DIO_1_O[4]  = FBIO_PAD_O[26];
assign FBIO_PAD_I[26] = DIO_1_I[4];
assign DIO_1_OE[5] = FBIO_PAD_OE[28];
assign DIO_1_O[5]  = FBIO_PAD_O[28];
assign FBIO_PAD_I[28] = DIO_1_I[5];
assign DIO_1_OE[6] = FBIO_PAD_OE[30];
assign DIO_1_O[6]  = FBIO_PAD_O[30];
assign FBIO_PAD_I[30] = DIO_1_I[6];
assign DIO_1_OE[7] = FBIO_PAD_OE[32];
assign DIO_1_O[7]  = FBIO_PAD_O[32];
assign FBIO_PAD_I[32] = DIO_1_I[7];
assign DIO_1_OE[8] = FBIO_PAD_OE[34];
assign DIO_1_O[8]  = FBIO_PAD_O[34];
assign FBIO_PAD_I[34] = DIO_1_I[8];
assign DIO_1_OE[10] = FBIO_PAD_OE[0];
assign DIO_1_O[10]  = FBIO_PAD_O[0];
assign FBIO_PAD_I[0] = DIO_1_I[10];
assign DIO_1_OE[11] = FBIO_PAD_OE[2];
assign DIO_1_O[11]  = FBIO_PAD_O[2];
assign FBIO_PAD_I[2] = DIO_1_I[11];
assign DIO_1_OE[12] = FBIO_PAD_OE[4];
assign DIO_1_O[12]  = FBIO_PAD_O[4];
assign FBIO_PAD_I[4] = DIO_1_I[12];
assign DIO_1_OE[13] = FBIO_PAD_OE[6];
assign DIO_1_O[13]  = FBIO_PAD_O[6];
assign FBIO_PAD_I[6] = DIO_1_I[13];

assign DIO_2_OE[0] = FBIO_PAD_OE[10];
assign DIO_2_O[0]  = FBIO_PAD_O[10];
assign FBIO_PAD_I[10] = DIO_2_I[0];
assign DIO_2_OE[1] = FBIO_PAD_OE[12];
assign DIO_2_O[1]  = FBIO_PAD_O[12];
assign FBIO_PAD_I[12] = DIO_2_I[1];
assign DIO_2_OE[2] = FBIO_PAD_OE[14];
assign DIO_2_O[2]  = FBIO_PAD_O[14];
assign FBIO_PAD_I[14] = DIO_2_I[2];
assign DIO_2_OE[3] = FBIO_PAD_OE[16];
assign DIO_2_O[3]  = FBIO_PAD_O[16];
assign FBIO_PAD_I[16] = DIO_2_I[3];
assign DIO_2_OE[6] = 1'b0;  // unconnected
assign DIO_2_O[6] = 1'b0;

assign DIO_3_OE[1:0] = 2'b00;   // unconnected
assign DIO_3_O[1:0]  = 2'b00;   
assign DIO_3_OE[3] = FBIO_PAD_OE[17];
assign DIO_3_O[3]  = FBIO_PAD_O[17];
assign FBIO_PAD_I[17] = DIO_3_I[3];
assign DIO_3_OE[4] = FBIO_PAD_OE[15];
assign DIO_3_O[4]  = FBIO_PAD_O[15];
assign FBIO_PAD_I[15] = DIO_3_I[4];
assign DIO_3_OE[5] = FBIO_PAD_OE[13];
assign DIO_3_O[5]  = FBIO_PAD_O[13];
assign FBIO_PAD_I[13] = DIO_3_I[5];
assign DIO_3_OE[6] = FBIO_PAD_OE[11];
assign DIO_3_O[6]  = FBIO_PAD_O[11];
assign FBIO_PAD_I[11] = DIO_3_I[6];
assign DIO_3_OE[7] = FBIO_PAD_OE[9];
assign DIO_3_O[7]  = FBIO_PAD_O[9];
assign FBIO_PAD_I[9] = DIO_3_I[7];
assign DIO_3_OE[8] = FBIO_PAD_OE[8];
assign DIO_3_O[8]  = FBIO_PAD_O[8];
assign FBIO_PAD_I[8] = DIO_3_I[8];
assign DIO_3_OE[9] = FBIO_PAD_OE[7];
assign DIO_3_O[9]  = FBIO_PAD_O[7];
assign FBIO_PAD_I[7] = DIO_3_I[9];
assign DIO_3_OE[10] = FBIO_PAD_OE[5];
assign DIO_3_O[10]  = FBIO_PAD_O[5];
assign FBIO_PAD_I[5] = DIO_3_I[10];
assign DIO_3_OE[11] = FBIO_PAD_OE[3];
assign DIO_3_O[11]  = FBIO_PAD_O[3];
assign FBIO_PAD_I[3] = DIO_3_I[11];
assign DIO_3_OE[12] = FBIO_PAD_OE[1];
assign DIO_3_O[12]  = FBIO_PAD_O[1];
assign FBIO_PAD_I[1] = DIO_3_I[12];
assign DIO_3_OE[13] = FBIO_PAD_OE[35];
assign DIO_3_O[13]  = FBIO_PAD_O[35];
assign FBIO_PAD_I[35] = DIO_3_I[13];
assign DIO_3_OE[15] = FBIO_PAD_OE[33];
assign DIO_3_O[15]  = FBIO_PAD_O[33];
assign FBIO_PAD_I[33] = DIO_3_I[15];
assign DIO_3_OE[16] = FBIO_PAD_OE[31];
assign DIO_3_O[16]  = FBIO_PAD_O[31];
assign FBIO_PAD_I[31] = DIO_3_I[16];
assign DIO_3_OE[17] = FBIO_PAD_OE[29];
assign DIO_3_O[17]  = FBIO_PAD_O[29];
assign FBIO_PAD_I[29] = DIO_3_I[17];
assign DIO_3_OE[18] = FBIO_PAD_OE[27];
assign DIO_3_O[18]  = FBIO_PAD_O[27];
assign FBIO_PAD_I[27] = DIO_3_I[18];
assign DIO_3_OE[19] = FBIO_PAD_OE[25];
assign DIO_3_O[19]  = FBIO_PAD_O[25];
assign FBIO_PAD_I[25] = DIO_3_I[19];
assign DIO_3_OE[20] = FBIO_PAD_OE[23];
assign DIO_3_O[20]  = FBIO_PAD_O[23];
assign FBIO_PAD_I[23] = DIO_3_I[20];
assign DIO_3_OE[21] = FBIO_PAD_OE[21];
assign DIO_3_O[21]  = FBIO_PAD_O[21];
assign FBIO_PAD_I[21] = DIO_3_I[21];
assign DIO_3_OE[22] = FBIO_PAD_OE[19];
assign DIO_3_O[22]  = FBIO_PAD_O[19];
assign FBIO_PAD_I[19] = DIO_3_I[22];

endmodule
