
module fpga_top (
  input  wire        GCLK,
  inout  wire [43:0] FPGA_PAD
);

wire        ref_clk;
wire        io_clk;
wire        sysclk;
wire [35:0] FBIO_PAD_I;
wire [35:0] FBIO_PAD_O;
wire [35:0] FBIO_PAD_OE;
wire        FBIO_PAD_RSTB;
wire        F2P_CLK_I;
wire        F2P_CLK_O;
wire        F2P_CLK_OE;
wire        P2F_CLK_I;
wire        P2F_CLK_O;
wire        P2F_CLK_OE;

// AXI slave port for B2A CPU access
wire [8:0]   FBIO_SL_AWID;
wire [31:0]  FBIO_SL_AWADDR;
wire [3:0]   FBIO_SL_AWLEN;
wire [2:0]   FBIO_SL_AWSIZE;
wire [1:0]   FBIO_SL_AWBURST;
wire [1:0]   FBIO_SL_AWLOCK;
wire [3:0]   FBIO_SL_AWCACHE;
wire [2:0]   FBIO_SL_AWPROT;
wire         FBIO_SL_AWVALID;
wire         FBIO_SL_AWREADY;

wire [8:0]   FBIO_SL_WID;
wire [63:0]  FBIO_SL_WDATA;
wire [7:0]   FBIO_SL_WSTRB;
wire         FBIO_SL_WLAST;
wire         FBIO_SL_WVALID;
wire         FBIO_SL_WREADY;

wire [8:0]   FBIO_SL_BID;
wire [1:0]   FBIO_SL_BRESP;
wire         FBIO_SL_BVALID;
wire         FBIO_SL_BREADY;

wire [8:0]   FBIO_SL_ARID;
wire [31:0]  FBIO_SL_ARADDR;
wire [3:0]   FBIO_SL_ARLEN;
wire [2:0]   FBIO_SL_ARSIZE;
wire [1:0]   FBIO_SL_ARBURST;
wire [1:0]   FBIO_SL_ARLOCK;
wire [3:0]   FBIO_SL_ARCACHE;
wire [2:0]   FBIO_SL_ARPROT;
wire         FBIO_SL_ARVALID;
wire         FBIO_SL_ARREADY;

wire [8:0]   FBIO_SL_RID;
wire [63:0]  FBIO_SL_RDATA;
wire [1:0]   FBIO_SL_RRESP;
wire         FBIO_SL_RLAST;
wire         FBIO_SL_RVALID;
wire         FBIO_SL_RREADY;
// AXI master1 interface -->
// AXI Write Address phase signals
wire [7:0]   FBIO_MA_AWID;
wire [31:0]  FBIO_MA_AWADDR;
wire [3:0]   FBIO_MA_AWLEN;
wire [2:0]   FBIO_MA_AWSIZE;
wire [1:0]   FBIO_MA_AWBURST;
wire [1:0]   FBIO_MA_AWLOCK;
wire [3:0]   FBIO_MA_AWCACHE;
wire [2:0]   FBIO_MA_AWPROT;
wire         FBIO_MA_AWVALID;
wire         FBIO_MA_AWREADY;
// AXI Write Data phase signals
wire [7:0]   FBIO_MA_WID;
wire [63:0]  FBIO_MA_WDATA;
wire [7:0]   FBIO_MA_WSTRB;
wire         FBIO_MA_WLAST;
wire         FBIO_MA_WVALID;
wire         FBIO_MA_WREADY;
// AXI Write Response phase signals
wire [7:0]   FBIO_MA_BID;
wire [1:0]   FBIO_MA_BRESP;
wire         FBIO_MA_BVALID;
wire         FBIO_MA_BREADY;

// AXI Read Address phase signals
wire [7:0]   FBIO_MA_ARID;
wire [31:0]  FBIO_MA_ARADDR;
wire [3:0]   FBIO_MA_ARLEN;
wire [2:0]   FBIO_MA_ARSIZE;
wire [1:0]   FBIO_MA_ARBURST;
wire [1:0]   FBIO_MA_ARLOCK;
wire [3:0]   FBIO_MA_ARCACHE;
wire [2:0]   FBIO_MA_ARPROT;
wire         FBIO_MA_ARVALID;
wire         FBIO_MA_ARREADY;
// AXI Read Data phase signals
wire [7:0]   FBIO_MA_RID;
wire [63:0]  FBIO_MA_RDATA;
wire [1:0]   FBIO_MA_RRESP;
wire         FBIO_MA_RLAST;
wire         FBIO_MA_RVALID;
wire         FBIO_MA_RREADY;
// <-- AXI master1 interface

// LoopBack AXI
assign FBIO_SL_AWID     = {1'b0, FBIO_MA_AWID};
assign FBIO_SL_AWADDR   = {4'h0, FBIO_MA_AWADDR[27:0]};    // Switch 0x7xxx_xxxx to 0x0xxx_xxxx;
assign FBIO_SL_AWLEN    = FBIO_MA_AWLEN;
assign FBIO_SL_AWSIZE   = FBIO_MA_AWSIZE;
assign FBIO_SL_AWBURST  = FBIO_MA_AWBURST;
assign FBIO_SL_AWLOCK   = FBIO_MA_AWLOCK;
assign FBIO_SL_AWCACHE  = FBIO_MA_AWCACHE;
assign FBIO_SL_AWPROT   = FBIO_MA_AWPROT;
assign FBIO_SL_AWVALID  = FBIO_MA_AWVALID;
assign FBIO_MA_AWREADY  = FBIO_SL_AWREADY;
assign FBIO_SL_WID      = {1'b0, FBIO_MA_WID};
assign FBIO_SL_WDATA    = FBIO_MA_WDATA;
assign FBIO_SL_WSTRB    = FBIO_MA_WSTRB;
assign FBIO_SL_WLAST    = FBIO_MA_WLAST;
assign FBIO_SL_WVALID   = FBIO_MA_WVALID;
assign FBIO_MA_WREADY   = FBIO_SL_WREADY;
assign FBIO_MA_BID      = FBIO_SL_BID[7:0];
assign FBIO_MA_BRESP    = FBIO_SL_BRESP;
assign FBIO_MA_BVALID   = FBIO_SL_BVALID;
assign FBIO_SL_BREADY   = FBIO_MA_BREADY;
assign FBIO_SL_ARID     = {1'b0, FBIO_MA_ARID};
assign FBIO_SL_ARADDR   = {4'h0, FBIO_MA_ARADDR[27:0]};    // Switch 0x7xxx_xxxx to 0x0xxx_xxxx;
assign FBIO_SL_ARLEN    = FBIO_MA_ARLEN;
assign FBIO_SL_ARSIZE   = FBIO_MA_ARSIZE;
assign FBIO_SL_ARBURST  = FBIO_MA_ARBURST;
assign FBIO_SL_ARLOCK   = FBIO_MA_ARLOCK;
assign FBIO_SL_ARCACHE  = FBIO_MA_ARCACHE;
assign FBIO_SL_ARPROT   = FBIO_MA_ARPROT;
assign FBIO_SL_ARVALID  = FBIO_MA_ARVALID;
assign FBIO_MA_ARREADY  = FBIO_SL_ARREADY;
assign FBIO_MA_RID      = FBIO_SL_RID[7:0];
assign FBIO_MA_RDATA    = FBIO_SL_RDATA;
assign FBIO_MA_RRESP    = FBIO_SL_RRESP;
assign FBIO_MA_RLAST    = FBIO_SL_RLAST;
assign FBIO_MA_RVALID   = FBIO_SL_RVALID;
assign FBIO_SL_RREADY   = FBIO_MA_RREADY;

pll0 u_clk_gen_0 (
  .clk_in1      (GCLK),
  .clk_out1     (io_clk),
  .clk_out2     (ref_clk),
  .clk_out3     (sysclk),
  .reset        (1'b0),
  .locked       (locked)
);

fbio_fpga u_fbio_0 (
  .ref_clk          (ref_clk),
  .io_clk           (io_clk),
  .SYSCLK          (sysclk),
  .mem_clk2x        (1'b0),

  .FBIO_SL_AWREADY  (FBIO_SL_AWREADY),
  .FBIO_SL_WREADY   (FBIO_SL_WREADY),
  .FBIO_SL_BID      (FBIO_SL_BID[8:0]),
  .FBIO_SL_BRESP    (FBIO_SL_BRESP[1:0]),
  .FBIO_SL_BVALID   (FBIO_SL_BVALID),
  .FBIO_SL_ARREADY  (FBIO_SL_ARREADY),
  .FBIO_SL_RID      (FBIO_SL_RID[8:0]),
  .FBIO_SL_RDATA    (FBIO_SL_RDATA[63:0]),
  .FBIO_SL_RRESP    (FBIO_SL_RRESP[1:0]),
  .FBIO_SL_RLAST    (FBIO_SL_RLAST),
  .FBIO_SL_RVALID   (FBIO_SL_RVALID),
  .FBIO_MA_AWID     (FBIO_MA_AWID[7:0]),
  .FBIO_MA_AWADDR   (FBIO_MA_AWADDR[31:0]),
  .FBIO_MA_AWLEN    (FBIO_MA_AWLEN[3:0]),
  .FBIO_MA_AWSIZE   (FBIO_MA_AWSIZE[2:0]),
  .FBIO_MA_AWBURST  (FBIO_MA_AWBURST[1:0]),
  .FBIO_MA_AWLOCK   (FBIO_MA_AWLOCK[1:0]),
  .FBIO_MA_AWCACHE  (FBIO_MA_AWCACHE[3:0]),
  .FBIO_MA_AWPROT   (FBIO_MA_AWPROT[2:0]),
  .FBIO_MA_AWVALID  (FBIO_MA_AWVALID),
  .FBIO_MA_WID      (FBIO_MA_WID[7:0]),
  .FBIO_MA_WDATA    (FBIO_MA_WDATA[63:0]),
  .FBIO_MA_WSTRB    (FBIO_MA_WSTRB[7:0]),
  .FBIO_MA_WLAST    (FBIO_MA_WLAST),
  .FBIO_MA_WVALID   (FBIO_MA_WVALID),
  .FBIO_MA_BREADY   (FBIO_MA_BREADY),
  .FBIO_MA_ARID     (FBIO_MA_ARID[7:0]),
  .FBIO_MA_ARADDR   (FBIO_MA_ARADDR[31:0]),
  .FBIO_MA_ARLEN    (FBIO_MA_ARLEN[3:0]),
  .FBIO_MA_ARSIZE   (FBIO_MA_ARSIZE[2:0]),
  .FBIO_MA_ARBURST  (FBIO_MA_ARBURST[1:0]),
  .FBIO_MA_ARLOCK   (FBIO_MA_ARLOCK[1:0]),
  .FBIO_MA_ARCACHE  (FBIO_MA_ARCACHE[3:0]),
  .FBIO_MA_ARPROT   (FBIO_MA_ARPROT[2:0]),
  .FBIO_MA_ARVALID  (FBIO_MA_ARVALID),
  .FBIO_MA_RREADY   (FBIO_MA_RREADY),
  .FBIO_SL_AWID     (FBIO_SL_AWID[8:0]),
  .FBIO_SL_AWADDR   (FBIO_SL_AWADDR[31:0]),
  .FBIO_SL_AWLEN    (FBIO_SL_AWLEN[3:0]),
  .FBIO_SL_AWSIZE   (FBIO_SL_AWSIZE[2:0]),
  .FBIO_SL_AWBURST  (FBIO_SL_AWBURST[1:0]),
  .FBIO_SL_AWLOCK   (FBIO_SL_AWLOCK[1:0]),
  .FBIO_SL_AWCACHE  (FBIO_SL_AWCACHE[3:0]),
  .FBIO_SL_AWPROT   (FBIO_SL_AWPROT[2:0]),
  .FBIO_SL_AWVALID  (FBIO_SL_AWVALID),
  .FBIO_SL_WID      (FBIO_SL_WID[8:0]),
  .FBIO_SL_WDATA    (FBIO_SL_WDATA[63:0]),
  .FBIO_SL_WSTRB    (FBIO_SL_WSTRB[7:0]),
  .FBIO_SL_WLAST    (FBIO_SL_WLAST),
  .FBIO_SL_WVALID   (FBIO_SL_WVALID),
  .FBIO_SL_BREADY   (FBIO_SL_BREADY),
  .FBIO_SL_ARID     (FBIO_SL_ARID[8:0]),
  .FBIO_SL_ARADDR   (FBIO_SL_ARADDR[31:0]),
  .FBIO_SL_ARLEN    (FBIO_SL_ARLEN[3:0]),
  .FBIO_SL_ARSIZE   (FBIO_SL_ARSIZE[2:0]),
  .FBIO_SL_ARBURST  (FBIO_SL_ARBURST[1:0]),
  .FBIO_SL_ARLOCK   (FBIO_SL_ARLOCK[1:0]),
  .FBIO_SL_ARCACHE  (FBIO_SL_ARCACHE[3:0]),
  .FBIO_SL_ARPROT   (FBIO_SL_ARPROT[2:0]),
  .FBIO_SL_ARVALID  (FBIO_SL_ARVALID),
  .FBIO_SL_RREADY   (FBIO_SL_RREADY),
  .FBIO_MA_AWREADY  (FBIO_MA_AWREADY),
  .FBIO_MA_WREADY   (FBIO_MA_WREADY),
  .FBIO_MA_BID      (FBIO_MA_BID[7:0]),
  .FBIO_MA_BRESP    (FBIO_MA_BRESP[1:0]),
  .FBIO_MA_BVALID   (FBIO_MA_BVALID),
  .FBIO_MA_ARREADY  (FBIO_MA_ARREADY),
  .FBIO_MA_RID      (FBIO_MA_RID[7:0]),
  .FBIO_MA_RDATA    (FBIO_MA_RDATA[63:0]),
  .FBIO_MA_RRESP    (FBIO_MA_RRESP[1:0]),
  .FBIO_MA_RLAST    (FBIO_MA_RLAST),
  .FBIO_MA_RVALID   (FBIO_MA_RVALID),

  .F2P_CLK_I        (F2P_CLK_I),
  .F2P_CLK_O        (F2P_CLK_O),
  .F2P_CLK_OE       (F2P_CLK_OE),
  .P2F_CLK_I        (P2F_CLK_I),
  .P2F_CLK_O        (P2F_CLK_O),
  .P2F_CLK_OE       (P2F_CLK_OE),
  .FBIO_PAD_I       (FBIO_PAD_I),
  .FBIO_PAD_O       (FBIO_PAD_O),
  .FBIO_PAD_OE      (FBIO_PAD_OE),
  .FBIO_PAD_RSTB    (FBIO_PAD_RSTB)
);

fbio_dip_wrap u_pad_0 (
  .DIO_1            (FPGA_PAD[13:0]),
  .DIO_2            (FPGA_PAD[20:14]),
  .DIO_3            (FPGA_PAD[43:21]),  
  .F2P_CLK_I        (F2P_CLK_I),
  .F2P_CLK_O        (F2P_CLK_O),
  .F2P_CLK_OE       (F2P_CLK_OE),
  .P2F_CLK_I        (P2F_CLK_I),
  .P2F_CLK_O        (P2F_CLK_O),
  .P2F_CLK_OE       (P2F_CLK_OE),
  .FBIO_PAD_I       (FBIO_PAD_I),
  .FBIO_PAD_O       (FBIO_PAD_O),
  .FBIO_PAD_OE      (FBIO_PAD_OE),
  .FBIO_PAD_RSTB    (FBIO_PAD_RSTB)
);

endmodule
